<?php

namespace Neutrino\Ion3Core\Database\Factories;
use Illuminate\Database\Eloquent\Factories\Factory;
use Neutrino\Ion3Core\Enums\RESOLookupPropertySubType;
use Neutrino\Ion3Core\Enums\RESOLookupPropertyType;
use Neutrino\Ion3Core\Enums\RESOLookupStandardStatus;

class ListingFactory extends Factory
{
    protected $model = 'App\Ion3\Models\Listing';

    public function definition(): array
    {
        $property_type = RESOLookupPropertyType::valuesArray()[array_rand(RESOLookupPropertyType::valuesArray())];
        $price = fake()->randomNumber(4) * 1000;
        return [
            'source' => 'Manual',
            'source_id' => fake()->regexify('[A-Z][0-9]{7}'),
            'address' => fake()->streetAddress(),
            'unit_number' => '',
            'city' => fake()->city(),
            'state' => fake()->stateAbbr(),
            'zip' => substr(fake()->postcode(), 0, 5),
            'county' => '',
            'country' => 'US',
            'area_major' => fake()->city(),
            'area_minor' => ucwords(fake()->word()),
            'building_name' => fake()->text(20),
            'school_district' => fake()->text(30),
            'property_type' => $property_type,
            'property_subtype' => RESOLookupPropertySubType::valuesArray()[array_rand(RESOLookupPropertySubType::valuesArray())],
            'listing_type' => 'Sale', // Lease
            'status' => RESOLookupStandardStatus::valuesArray()[array_rand(RESOLookupStandardStatus::valuesArray())],
            'price' => $price,
            'price_original' => $price,
            'price_closed' => 0,
            'beds' => fake()->numberBetween(0, 5),
            'baths_quarter' => fake()->numberBetween(0, 1),
            'baths_half' => fake()->numberBetween(0, 2),
            'baths_three_quarter' => fake()->numberBetween(0, 1),
            'baths_full' => fake()->numberBetween(1, 5),
            'baths_total' => fake()->randomFloat(1, 1, 5),
            'living_area' => fake()->numberBetween(500, 8000),
            'lot_size_sqft' => fake()->numberBetween(600, 20000),
            'lot_size_acres' => fake()->randomFloat(2, 0, 100),
            'year_built' => date('Y', fake()->dateTimeThisDecade()->getTimestamp()),
            'parcel_number' => fake()->uuid(),
            'show_online' => 1,
            'show_address' => 1,
            'show_map' => 1,
            'show_price' => 1,
            'is_ours' => fake()->numberBetween(0, 1),
            'is_duplicate' => 0,
            'latitude' => fake()->latitude(7, 85),
            'longitude' => fake()->longitude(-67, -124),
            'list_date' => fake()->dateTimeThisYear(),
            'close_date' => null,
            'pending_date' => null,
            'search_type' => $property_type,
        ];
    }
}
