<?php

use Neutrino\Ion3Core\Enums\RESOLookupPropertySubType;
use Neutrino\Ion3Core\Enums\RESOLookupPropertyType;
use Neutrino\Ion3Core\Enums\RESOLookupStandardStatus;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        $enums = [
            'property_type' => RESOLookupPropertyType::valuesArray(),
            'property_subtype' => RESOLookupPropertySubType::valuesArray(),
            'status' => RESOLookupStandardStatus::valuesArray(),
        ];
        array_unshift($enums['property_type'], '');
        array_unshift($enums['property_subtype'], '');

        Schema::create('listings', function (Blueprint $table) use ($enums) {
            $table->id();
            $table->string('source', 16);
            $table->string('source_id', 36); // "MLS" Number

            $table->string('address', 64);
            $table->string('unit_number', 24);
            $table->string('city', 32);
            $table->string('state', 2);
            $table->string('zip', 10);
            $table->string('county', 32);
            $table->string('country', 32);
            $table->string('area_major', 64);
            $table->string('area_minor', 64);
            $table->string('building_name', 64);
            $table->string('school_district', 64);

            $table->enum('property_type', $enums['property_type']);
            $table->enum('property_subtype', $enums['property_subtype']);
            $table->enum('listing_type', ['Sale', 'Lease', 'Sale or Lease']);
            $table->string('search_type', 32);
            $table->enum('status', $enums['status']);
            $table->integer('price');
            $table->integer('price_original');
            $table->integer('price_closed');
            $table->smallInteger('beds');
            $table->smallInteger('baths_quarter');
            $table->smallInteger('baths_half');
            $table->smallInteger('baths_three_quarter');
            $table->smallInteger('baths_full');
            $table->decimal('baths_total', 4, 2);
            $table->integer('living_area');
            $table->integer('lot_size_sqft');
            $table->decimal('lot_size_acres', 9, 2);
            $table->smallInteger('year_built');
            $table->string('parcel_number', 128);

            $table->boolean('show_online');
            $table->boolean('show_address');
            $table->boolean('show_map');
            $table->boolean('show_price');

            $table->boolean('is_ours');
            $table->boolean('is_duplicate');

            $table->decimal('latitude', 17, 14)->nullable();
            $table->decimal('longitude', 17, 14)->nullable();

            $table->dateTimeTz('list_date');
            $table->dateTimeTz('close_date')->nullable();
            $table->dateTimeTz('pending_date')->nullable();

            $table->softDeletesTz();
            $table->timestampsTz();

            $table->index('source');
            $table->index('source_id');
            $table->index('show_online');
            $table->index('property_type');
            $table->index('property_subtype');
            $table->index('listing_type');
            $table->index('status');
            $table->index('price');
            $table->index('beds');
            $table->index('is_ours');
            $table->index('is_duplicate');
            $table->index('list_date');
            $table->index('close_date');
            $table->index('pending_date');
            $table->index('deleted_at');
            $table->index('created_at');
            $table->index('updated_at');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('listings');
    }
};
