<?php

namespace Neutrino\Ion3Core\Database\Seeders;

// use Illuminate\Database\Console\Seeds\WithoutModelEvents;
use App\Ion3\Models\Agent;
use App\Ion3\Models\Branch;
use App\Ion3\Models\Listing;
use App\Ion3\Models\ListingMedia;
use App\Ion3\Models\Office;
use App\Models\User;
use Illuminate\Database\Seeder;
use Illuminate\Support\Facades\DB;
use Neutrino\Ion3Core\Models\Ion3BranchOfficeSource;
use Neutrino\Ion3Core\Models\Ion3UserAgentSource;

class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     */
    public function run(): void
    {
        // Generate records
        $this->call(ListingSeeder::class);
        $this->call(OfficeSeeder::class);
        $this->call(BranchSeeder::class);

        // Sync up listings with agents and offices
        $listings = Listing::all();
        $agents = Agent::all();

        foreach ($listings as $listing) {
            $selectedAgents = $agents->random(rand(1, 4));
            foreach ($selectedAgents as $key => $agent) {
                if ($key < 2) {
                    $type = 'selling';
                } else {
                    $type = 'buying';
                }
                $listing->agents()->attach($agent->id, [
                    'active' => true,
                    'type' => $type,
                    'position' => ($key % 2) + 1
                ]);

                $listing->offices()->attach($agent->office->id, [
                    'active' => true,
                    'type' => $type,
                    'position' => ($key % 2) + 1
                ]);
            }

            // Add some media too
            $mediaCount = rand(1, 10);
            for ($position = 0; $position < $mediaCount; $position++) {
                ListingMedia::create([
                    'listing_id' => $listing->id,
                    'source' => 'Manual',
                    'type' => 'Photo',
                    'position' => $position,
                    'url' => fake()->imageUrl(),
                    'caption' => fake()->sentence(),
                ]);
            }
        }

        // Add source values for agents and offices
        // First, create agent source values for users, 1 agent per user
        $users = User::with('agent_sources')->inRandomOrder()->take(10)->get();
        $agents = Agent::inRandomOrder()->take(10)->get();
        foreach($users as $k => $user) {
            $currentAgent = $agents[$k];
            Ion3UserAgentSource::create([
                'user_id' => $user->id,
                'source' => $currentAgent->source,
                'source_id' => $currentAgent->source_id,
            ]);
            $currentAgent->update(['user_id' => $user->id]);
        }

        // Now, do the same on branches/offices
        $branches = Branch::with('office_sources')->get();
        $agentsWithUsersOfficeIDs = Agent::whereNotNull('user_id')
            ->pluck('office_id')
            ->toArray();
        $offices = Office::whereIn('id', $agentsWithUsersOfficeIDs)
            ->take($branches->count())
            ->get();
        foreach($branches as $k => $branch) {
            if (isset($offices[$k])) {
                $currentOffice = $offices[$k];
                Ion3BranchOfficeSource::create([
                    'branch_id' => $branch->id,
                    'source' => $currentOffice->source,
                    'source_id' => $currentOffice->source_id,
                ]);
                $currentOffice->update(['branch_id' => $branch->id]);
            }
        }

        // Assign users to branches based on those connections
        // This could certainly be optimized
        foreach($users as $user) {
            $agent = Agent::where('user_id', $user->id)->first();
            if ($agent) {
                $office = Office::find($agent->office_id);
                if ($office->branch_id) {
                    DB::table('branch_user')->insert([
                        'branch_id' => $office->branch_id,
                        'user_id' => $user->id,
                    ]);
                }
            }
        }
    }
}
