<?php

namespace Neutrino\Ion3Core\Console\Commands;

use App\Models\User;
use Illuminate\Console\Command;
use Neutrino\Ion3Core\Traits\Ion3UserTrait;

class Ion3SeedCommand extends Command
{
    protected $signature = 'ion3:seed
                            {--l|listings=10 : How many listings to generate}';

    protected $description = 'Seed the Ion3 database tables with dummy listings.';

    public function handle()
    {
        // User model required
        if (!in_array(Ion3UserTrait::class, class_uses_recursive(User::class))) {
            $this->error("\App\Models\User.php must use Ion3UserTrait, please see installation docs to continue.");
            return 1;
        }

        // Check if our Ion3 custom models exist, and if not let the user know
        try {
            class_exists(\App\Ion3\Models\Listing::class);
        } catch (\Throwable $e) {
            $this->line("\e[31mIon3 not installed, please run\e[0m php artisan vendor:publish --tag=ion3-install");
            return 1;
        }

        // Set number of listings for later reference
        $numberOfListings = $this->option('listings');
        app()->singleton('ion3SeedListingsCount', function() use ($numberOfListings) {
            return $numberOfListings;
        });

        $this->call('db:seed', [
            '--class' => \Neutrino\Ion3Core\Database\Seeders\DatabaseSeeder::class
        ]);

        $this->info('Ion3 seeding complete.');

        return 0; // Success
    }
}
