<?php

namespace Neutrino\Ion3Core\Models;

use App\Models\User;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Neutrino\Ion3Core\Database\Factories\AgentFactory;

class Ion3Agent extends Model
{
    use HasFactory;

    protected $table = 'agents';
    protected $officeClass = \App\Ion3\Models\Office::class;
    protected $listingClass = \App\Ion3\Models\Listing::class;
    protected $hidden = ['created_at', 'updated_at'];

    public function __construct(array $attributes = [])
    {
        parent::__construct($attributes);
    }

    protected static function newFactory()
    {
        return AgentFactory::new();
    }

    public function office(): BelongsTo
    {
        return $this->belongsTo($this->officeClass, 'office_id');
    }

    public function users()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function listings(): BelongsToMany
    {
        return $this->belongsToMany($this->listingClass, 'agent_listing', 'agent_id', 'listing_id')
            ->withTimestamps()
            ->withPivot('type', 'position', 'active');
    }
}
