<?php

namespace Neutrino\Ion3Core\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Neutrino\Ion3Core\Database\Factories\ListingFactory;

class Ion3Listing extends Model
{
    use HasFactory;

    protected $table = 'listings';
    protected $agentClass = \App\Ion3\Models\Agent::class;
    protected $officeClass = \App\Ion3\Models\Office::class;
    protected $listingCustomClass = \App\Ion3\Models\ListingCustom::class;
    protected $listingMediaClass = \App\Ion3\Models\ListingMedia::class;
    protected $listingMetaClass = \App\Ion3\Models\ListingMeta::class;


    static function newFactory()
    {
        return ListingFactory::new();
    }

    public function custom(): HasOne
    {
        return $this->hasOne($this->listingCustomClass);
    }

    public function meta(): HasMany
    {
        return $this->hasMany($this->listingMetaClass, 'listing_id');
    }

    public function media(): HasMany
    {
        return $this->hasMany($this->listingMediaClass, 'listing_id');
    }

    public function agents(): BelongsToMany
    {
        return $this->belongsToMany($this->agentClass, 'agent_listing', 'listing_id', 'agent_id')
            ->withTimestamps()
            ->withPivot('type', 'position', 'active');
    }

    public function offices(): BelongsToMany
    {
        return $this->belongsToMany($this->officeClass, 'listing_office', 'listing_id', 'office_id')
            ->withTimestamps()
            ->withPivot('type', 'position', 'active');
    }

    public function orderedAgents()
    {
        return $this->belongsToMany($this->agentClass, 'agent_listing')
            ->wherePivot('active', 1) // Only include active agents
            ->orderByPivot('type') // Order by type in the pivot table
            ->orderByPivot('position'); // Then order by position
    }

    public function getAddress(): String
    {
        return $this->address;
    }
}
